/* commonhelp.h: handle command line help common to omindex and scriptindex.
 *
 * Copyright (C) 2005,2006,2007 Olly Betts
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef OMEGA_INCLUDED_COMMONHELP_H
#define OMEGA_INCLUDED_COMMONHELP_H

void print_package_info(const char *name);
void print_stemmer_help(const char *spaces);
void print_help_and_version_help(const char *spaces, char short_version = 'v');

#endif // OMEGA_INCLUDED_COMMONHELP_H
